@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: ExportList.pm,v 1.5 2003/12/10 02:37:24 nothingmuch Exp $
+# $Id: ExportList.pm,v 1.1 2003/11/29 14:35:24 nothingmuch Exp $
 
 package Object::Meta::Plugin::ExportList; # an object representing the skin of a plugin - what can be plugged and unseamed at the top level.
 
@@ -12,50 +12,41 @@ use warnings;
 # you could laxen these limits by writing your own ExportList, which will use code refs, and thus allow a plugin to nibble methods from other classes without base classing.
 # you'd also have to subclass Object::Meta::Plugin::Host to handle coderefs. Perhaps a dualvalue system could be useful.
 
-our $VERSION = 0.02;
+our $VERSION = 0.01;
 
 sub new {
 	my $pkg = shift;
 	my $plugin = shift;
 	
-	my $self = bless {
-		plugin => $plugin,
-		info => (ref $_[0] ? shift : Object::Meta::Plugin::ExportList::Info->new()),
-	}, $pkg;
-	
 	my @methods = @_;
 	
-	if (@methods){	
+	if (@_){	
 		my %list = map { $_, undef } $plugin->exports(); # used to cross out what's not exported	
-		$self->{methods} = [ grep { exists $list{$_} } @methods ]; # filter the method list to be only what works;
+		bless [ $plugin, [ grep { exists $list{$_} } @methods ] ], $pkg; # filter the method list to be only what works
 	} else {
-		$self->{methods} = [ $plugin->exports() ]; # everything unless otherwise stated
+		bless [ $plugin, [ $plugin->exports() ] ], $pkg; # everythin unless otherwise stated
 	}
-	
-	$self;
 }
 
 sub plugin {
 	my $self = shift;
-	$self->{plugin};
+	$self->[0];
 }
 
-sub exists {
+sub exists { # $$$
 	my $self = shift;
 
-	$self->{index} = { map { $_, undef } @{ $self->{methods} } } unless (exists $self->{index});
-	
 	if (wantarray){ # return a grepped list
-		return grep { exists $self->{index}{$_} } @_;
+		my @methods = @_;
 	} else { # return a true or false
-		return exists $self->{index}{$_[0]};
+		my $method = shift;
 	}
 }
 
 sub list { # list all under plugin
 	my $self = shift;
 	
-	return @{ $self->{methods} };
+	return @{ $self->[1] };
 }
 
 sub merge { # or another exoprt list into this one
@@ -63,7 +54,7 @@ sub merge { # or another exoprt list into this one
 	my $x = shift;
 	
 	my %uniq;
-	@{ $self->{methods} } = grep { not $uniq{$_}++ } @{ $self->{methods} }, $x->list();
+	@{ $self->[1] } = grep { not $uniq{$_}++ } @{ $self->[1] }, $x->list();
 
 	$self;
 }
@@ -73,37 +64,7 @@ sub unmerge { # and (not|complement) another export list into this one
 	my $x = shift;
 	
 	my %seen = map { $_, undef } $x->list();
-	@{ $self->{methods} } = grep { not exists $seen{$_} } @{ $self->{methods} };
-}
-
-sub info {
-	my $self = shift;
-	
-	$self->{info} = shift if (@_);
-	
-	$self->{info};
-}
-
-package Object::Meta::Plugin::ExportList::Info; # for now it's basically a method->hashkey translator
-
-our $AUTOLOAD;
-
-sub new {
-	my $pkg = shift;
-	bless {@_ ? @_ : qw/
-		style	implicit
-	/}, $pkg;
-};
-
-sub AUTOLOAD {
-	my $self = shift;
-	$AUTOLOAD =~ /.*::(.*)$/;
-	my $method = $1;
-	return if $method eq 'DESTROY';
-	
-	$self->{$method} = shift if (@_);
-	
-	$self->{$method};
+	@{ $self->[1] } = grep { not exists $seen{$_} } @{ $self->[1] };
 }
 
 1; # Keep your mother happy.
@@ -114,7 +75,7 @@ __END__
 
 =head1 NAME
 
-Object::Meta::Plugin::ExportList - An implementation of a very simple, string only export list, for use with Useful:: plugins.
+Object::Meta::Plugin::ExportList - an implementation of a very simple, string only export list.
 
 =head1 SYNOPSIS
 
@@ -157,51 +118,29 @@ An export list is an object a plugin hands over to a host, stating what it is go
 
 =over 4
 
-=item new PLUGIN [ INFO ] [ METHODS ... ]
+=item new PLUGIN [ METHODS ... ]
 
-Creates a new export list object. If it is a reference, it will be assumed that the second argument is an info object. Provided that is the case, no info object will be created, and the argued one will be used in place. Any remaining arguments will be method names to be exported. If none are specified, the return value from the plugin's C<exports> method is used.
-
-=item list
-
-Returns a list of exported method names.
+Creates a new export list object. When passed only a plugin, and no method names as additional arguments, 
 
 =item plugin
 
 Returns the reference to the plugin object it represents.
 
-=item exists METHODS ...
+=item exists METHOD
 
-In scalar context will return truth if the first argument is a method that exists in the export list. In list context, it will return the method names given in @_, with the inexistent ones excluded.
+Returns truth if the method stated is exported.
+
+=item list METHOD
+
+Returns a list of exported method names.
 
 =item merge EXPORTLIST
 
-Performs an I<or> with the methods of the argued export list.
+Performs an OR with the methods of the argued export list.
 
 =item unmerge EXPORTLIST
 
-Performs an I<and> of the I<complement> of the argued export list.
-
-=item info [ INFO ]
-
-Stores meta information regarding the plugin it represents. It's stored in the export list because the export list is what you use to communicate with the host.
-
-Currently only the I<style> field is defined, which will effect the kind of context shim that is created. The default is the most naive, but also the least efficient - the tied context.
-
-=back
-
-=head1 Object::Meta::Plugin::ExportList::Info
-
-This is just a hash, basically. It has an autoloader which will fetch a hash key by the method name with no arguments, or set the value to the first argument if it's there.
-
-Deletion is not supported.
-
-=head2 Known attributes
-
-=over 4
-
-=item style
-
-Defines the behavior of the context shim. See L<Object::Meta::Plugin::Host> for a description of how this works.
+Performs an AND of the COMPLEMENT of the argued export list.
 
 =back
 
@@ -219,10 +158,6 @@ Relies on the plugin implementation to provide a non-mandatory extension - the C
 
 Not that I know of, for the while being at least.
 
-=head1 TODO
-
-Nothing right now.
-
 =head1 COPYRIGHT & LICENSE
 
 	Copyright 2003 Yuval Kogman. All rights reserved.
@@ -235,6 +170,6 @@ Yuval Kogman <nothingmuch@woobling.org>
 
 =head1 SEE ALSO
 
-L<Object::Meta::Plugin>, L<Object::Meta::Plugin::Useful>, L<Object::Meta::Plugin::Host>.
+L<Object::Meta::Plugin>, L<Object::Meta::Plugin::Useful>, L<Object::Meta::Plugin::Host>
 
 =cut
