@@ -1,23 +1,16 @@
 #!/usr/bin/perl
-# $Id: Generic.pm,v 1.6 2003/12/10 03:52:30 nothingmuch Exp $
+# $Id: Generic.pm,v 1.1 2003/11/29 14:35:24 nothingmuch Exp $
 
 package Object::Meta::Plugin::Useful::Generic; # an extended base class with some logical features $$$ ## rename to Usefull::Generic;
 
 use strict;
 use warnings;
+use warnings::register;
 
 use base 'Object::Meta::Plugin::Useful';
 
 our $VERSION = 0.01;
 
-sub new {
-	my $pkg = shift;
-	
-	bless {
-		exports => [],
-	}, $pkg;
-}
-
 sub export { # utility method: export a list of method names
 	my $self = shift;
 	my @try_export = @_;
@@ -45,12 +38,12 @@ __END__
 
 =head1 NAME
 
-Object::Meta::Plugin::Useful::Generic - A generic useful plugin base class.
+Object::Meta::Plugin::Useful::Generic - a generic useful plugin base class.
 
 =head1 SYNOPSIS
 
 	package MyFoo;
-	use base "Object::Meta::Plugin::Useful::Generic";
+	use bas "Object::Meta::Plugin::Useful::Generic";
 
 	sub new {
 		my $pkg = shift;
@@ -74,10 +67,6 @@ This provides a very simple base class for a plugin. It uses the method C<export
 
 =over 4
 
-=item exports
-
-Returns the list of method names as created by C<export>.
-
 =item export METHODS ...
 
 This method takes a list of method names, and makes sure they are all implemented (C<$self->can($method)>) and so forth. It then makes notes of what remains, and will return these values when the exports method is called by the standard export list implementation.
@@ -93,31 +82,22 @@ This method takes a list of method names, and makes sure they are all implemente
 Will emit warnings if lexical warnings are asked for. It will bark when C<$self->can($method)> is not happy. You can suppress it with
 
 	no warnings 'MyFoo';
-	
-Or whatever.
 
-This also means that you will need to
+Or
 
-	use warnings::register;
+	no warnings 'Object::Meta::Plugin::Useful::Generic';
 
-
-The errors are not fatal like they are in L<Object::Meta::Plugin::Host>, because this plugin implementation does not need to be necessarily plugged into the L<Object::Meta::Plugin::Host> implementation.
+Depending on what level you'd like the warnings to be suppressed.
 
 =back
 
 =head1 BUGS
 
-Nothing I know of.
-
-=head1 TODO
-
-Nothing right now.
-
-=head1 ACKNOWLEDGMENTS
-
 =over 4
 
-=item Mike Castle, for spotting a typo.
+=item *
+
+Namespace is not well defined within the hash, nor is it guaranteed that it will never be extended.
 
 =back
 
