@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: Meta.pm,v 1.8 2003/12/10 02:39:55 nothingmuch Exp $
+# $Id: Meta.pm,v 1.2 2003/11/29 14:48:37 nothingmuch Exp $
 
 package Object::Meta::Plugin::Useful::Meta; # a plugin base class which subclasses Object::Meta::Plugin::Host - a meta plugin
 
@@ -8,7 +8,16 @@ use warnings;
 
 use base qw/Object::Meta::Plugin::Host Object::Meta::Plugin::Useful/;
 
-our $VERSION = 0.01;
+sub new {
+	my $pkg = shift;
+	
+	my $self = $pkg->SUPER::new(); # host;
+	
+	$self->{exported} = undef;
+	$self->{exports} = [];
+	
+	$self;
+}
 
 sub exports {
 	keys %{ $_[0]->methods };
@@ -23,7 +32,7 @@ __END__
 
 =head1 NAME
 
-Object::Meta::Plugin::Useful::Meta - A subclass of Object::Meta::Plugin::Useful and Object::Meta::Plugin::Host, base class for hosts which are plugins.
+Object::Meta::Plugin::Useful::Meta - a subclass of Object::Meta::Plugin::Useful and Object::Meta::Plugin::Host, base class for hosts which are plugins.
 
 =head1 SYNOPSIS
 
@@ -39,23 +48,13 @@ Object::Meta::Plugin::Useful::Meta - A subclass of Object::Meta::Plugin::Useful
 
 This is an L<Object::Meta::Plugin::Host> and more. It provides the necessary methods to treat a host as a plugin. It is not the most elegant solution, see C<CAVEATS>.
 
-=head1 METHODS
-
-=over 4
-
-=item exports
-
-Returns the methods of the host it subclasses.
-
-=back
-
 =head1 CAVEATS
 
 =over 4
 
 =item *
 
-Somewhat defies the purpose of plugging things in. It is possible (and even tested for, look at L<t/lib/OMPTest.pm>) to plug a plugin into a host, and have that plugin provide plugin capabilities. Such an implementation would look like this:
+Somewhat defies the purpose of plugging things in. It is possible (and even tested for) to plug a plugin into a host, and have that plugin provide plugin capabilities. Such an implementation would look like this:
 
 
 	package SuperPlugin;
@@ -93,16 +92,6 @@ Somewhat defies the purpose of plugging things in. It is possible (and even test
 
 =back
 
-=head1 BUGS
-
-Nada.
-
-=head1 TODO
-
-Nothing right now.
-
-=head1
-
 =head1 COPYRIGHT & LICENSE
 
 	Copyright 2003 Yuval Kogman. All rights reserved.
